pygeodesy.triaxials.bases

Package pygeodesy :: Package triaxials :: Module bases |
[frames] | no frames]

# Module bases

(INTERNAL) Base classes for ordered triaxial ellipsoid classes Conformal, Conformal3, Triaxial, Triaxial3 and unordered Triaxial_.

Transcoded to pure Python from Karney's GeographicLib 2.7 C++ classes Ellipsoid3, Cartesian3 and Conformal3.

GeographicLib 2.5.2 C++ class JacobiConformal.

Copyright (C) Charles Karney (2008-2024, 2025) and licensed under the MIT/X11 License. For more information, see the GeographicLib 2.5.2 and 2.7 documentation.

Enum-like `Lat-/Longitude Kinds (LLK)`, see Karney's coord:

Version: 26.02.15

Classes
| LLK Enum-like `Lat-/Longitude Kinds (LLK)`, see coord.
| _UnOrderedTriaxialBase (INTERNAL) Base class for all unordered triaxial classes.
| _OrderedTriaxialBase (INTERNAL) Base class for all ordered triaxial classes.
| _Triaxial3Base (INTERNAL) Base class for unordered triaxial`3` classes.
| TriaxialError Raised for any triaxial issue.

Variables
| __all__ = `_ALL_LAZY.triaxials_bases`
| LLK.CONFORMAL Jacobi conformal X and Y projection
| LLK.ELLIPSOIDAL Ellipsoidal lat-, longitude and heading `bet`, `omg`, `alp` (Ang)
| LLK.GEOCENTRIC Geocentric lat-, longitude and heading `phi`", `lam`" and `zet` (Ang)
| LLK.GEOCENTRIC_X Geocentric with pole along major X axis
| LLK.GEODETIC Geodetic lat-, longitude and heading `phi`, `lam` and `zet` (Ang)
| LLK.GEODETIC_LON0 Geodetic lat-, longitude - lon0 and heading `phi`, `lam` and `zet` (Ang) @var LLK.GEOGRAPHIC = LLK.GEODETIC
| LLK.GEODETIC_X Geodetic with pole along major X axis
| LLK.PARAMETRIC Parametric lat-, longitude and heading `phi`', `lam`' and `zet` (Ang)
| LLK.PARAMETRIC_X Parametric with pole along major X axis @var LLK.PLANETODETIC = LLK.GEODETIC @var LLK.PLANETOCENTRIC = LLK.GEOCENTRIC